pub struct BotSideBus { /* private fields */ }Expand description
The bot-side port for pushing inbound messages and consuming outbound messages.
Implementations
Sourceimpl BotSideBus
impl BotSideBus
Sourcepub async fn push(&self, msg: InboundMessage) -> Result<(), AgentError>
pub async fn push(&self, msg: InboundMessage) -> Result<(), AgentError>
Push an inbound message onto the bus for the agent to consume.
Sourcepub async fn recv_outbound(&mut self) -> Option<OutboundMessage>
pub async fn recv_outbound(&mut self) -> Option<OutboundMessage>
Receive the next outbound message from the agent.