pub fn route(input: &str) -> RouteResultExpand description
Route raw user input into either a slash command or natural language.
Only inputs starting with / are treated as commands. Everything else
goes to the LLM pipeline as natural language.
pub fn route(input: &str) -> RouteResultRoute raw user input into either a slash command or natural language.
Only inputs starting with / are treated as commands. Everything else
goes to the LLM pipeline as natural language.